<?php

/**
 * @package     Sprinix_EstimateDate
 * @copyright   Copyright (c) 2023 Sprinix Technolabs pvt Ltd.. (https://www.sprinix.com)
 */
namespace Sprinix\EstimateDate\Block;

use Magento\Framework\Registry;
use Sprinix\EstimateDate\Helper\Data;
use Magento\Framework\View\Element\Template\Context;
use Magento\Framework\View\Element\Template;

/**
 * Class ProductDetail
 * @package Sprinix\EstimateDate\Block
 */
class ProductDetail  extends Template
{
    /**
     * @var Registry
     */
    protected $registry;
    /**
     * @var Data
     */
    protected $helper;

    /**
     * ProductDetail constructor.
     * @param Registry $registry
     * @param Data $helper
     * @param Context $context
     * @param array $data
     */
    public function __construct(
        Registry $registry,
        Data $helper,
        Context $context,
        array $data = []
    ) {
        parent::__construct($context, $data);
        $this->registry = $registry;
        $this->helper = $helper;
    }

    /**
     * @return string
     */
    public function productDetails()
    {
        $product = $this->registry->registry('current_product');
        $productType = $product->getTypeId();
        $position = $this->helper->getPageSelect();
        $delivery_date_text = $this->helper->showDeliveryText();
        $checkDelivery = $this->helper->checkDeliveryAvailable();
        if ($this->helper->isEnabled()) {
            if($checkDelivery){
              if (@in_array(Data::PRODUCT, $position)) {
                if ($product) {
                    if ($productType == Data::SIMPLE || $productType == Data::BUNDLE
                        || $productType == Data::CONFIGURABLE ||$productType == Data::GROUPED ) {
                        $deliveryDate = $this->helper->deliveryDate($product);
                        if ($deliveryDate) {
                            $deliveryDate = $delivery_date_text . " : -  " . $deliveryDate;
                            return $deliveryDate;
                        }
                    }
                }
              }
            }
        }
    }
    /**
     * @return mixed
     */
    public function configDate()
    {
        $product = $this->registry->registry('current_product');
        $delivery_date_text = $this->helper->showDeliveryText();
        $position = $this->helper->getPageSelect();
        $checkDelivery = $this->helper->checkDeliveryAvailable();
        $productType = $product->getTypeId();
         if ($this->helper->isEnabled()) {
             if ($checkDelivery) {
                 if (@in_array(Data::PRODUCT, $position)) {
                    if ($product) {
                        if ($productType == Data::CONFIGURABLE) {
                            $daysType = "from_days";
                            $from = $this->helper->configFromTo($product, $daysType);
                            $daysType = "to_days";
                            $to = $this->helper->configFromTo($product, $daysType);
                            foreach ($from as $key => $values) {
                                $date[$key] = $delivery_date_text . " -: " . $from[$key] . " - " . $to[$key];
                            }
                            return $date;
                        }
                    }
                }
             }
         }
    }

    /**
     * @return mixed
     */
    public function moduleEnable(){
        return $this->helper->isEnabled();
    }
}
