<?php

/**
 * @package     Sprinix_EstimateDate
 * @copyright   Copyright (c) 2023 Sprinix Technolabs pvt Ltd.. (https://www.sprinix.com)
 */
namespace Sprinix\EstimateDate\Block;

use Magento\Checkout\Model\Session;
use Magento\Sales\Model\OrderRepository;
use Sprinix\EstimateDate\Helper\Data;
use Magento\Framework\Serialize\SerializerInterface;
use Magento\Framework\View\Element\Template\Context;
use Magento\Framework\View\Element\Template;
use Psr\Log\LoggerInterface;

/**
 * Class Success
 * @package Sprinix\EstimateDate\Block
 */
class Success extends Template
{
    /**
     * @var Session
     */
    protected $checkoutSession;

    /**
     * @var OrderRepository
     */
    protected $orderRepository;

    /**
     * @var Data
     */
    protected $helper;

    /**
     * @var SerializerInterface
     */
    protected $serializer;

    /**
     * @var LoggerInterface
     */
    private  $logger;

    /**
     * Success constructor.
     * @param Session $checkoutSession
     * @param OrderRepository $orderRepository
     * @param Data $helper
     * @param SerializerInterface $serializer
     * @param LoggerInterface $logger
     * @param Context $context
     * @param array $data
     */
    public function __construct(
        Session $checkoutSession,
        OrderRepository $orderRepository,
        Data $helper,
        SerializerInterface $serializer,
        LoggerInterface $logger,
        Context $context,
        array $data = []
    ) {
        parent::__construct($context, $data);
        $this->checkoutSession = $checkoutSession;
        $this->orderRepository = $orderRepository;
        $this->helper = $helper;
        $this->serializer = $serializer;
        $this->logger = $logger;
    }

    /**
     * @return string|void
     */
    public function getDeliveryDate()
    {
       try {
          $lastOrderId = $this->checkoutSession->getLastOrderId();
          $order = $this->orderRepository->get($lastOrderId);
          $itemCollection = $order->getItemsCollection();
          $delivery_date_text = $this->helper->showDeliveryText();
          $position = $this->helper->getPageSelect();
          $from = $to = [];
          foreach ($itemCollection as $item) {
              $deliveryDate = $item->getDeliveryDate();
              if ($deliveryDate) {
                  $estimateDate = $this->serializer->unserialize($deliveryDate);
                  foreach ($estimateDate as $eachDate) {
                      $date_delivery = $eachDate['value'];
                      $date_delivery = @explode('-', $date_delivery);
                      $from_date = $date_delivery[0];
                      $from[] = $from_date;
                      $to_date = $date_delivery[1];
                      $to[] = $to_date;
                  }
              }
          }
          $from = @min($from);
          $to = @max($to);
          if ($this->helper->isEnabled()) {
                 if (@in_array(Data::SUCCESS, $position)) {
                   if ($delivery_date_text && $from && $to) {
                       $deliveryDate = "<b>" . $delivery_date_text . " : -  " . $from . " - " . $to;
                       return $deliveryDate;
                   }
               }
          }
       }
       catch (\Exception $e) {
          $this->logger->info($e->getMessage());
       }
       return;
    }

    /**
     * @return mixed
     */
    public function moduleEnable(){
        return $this->helper->isEnabled();
    }
}

