<?php

/**
 * @package     Sprinix_EstimateDate
 * @copyright   Copyright (c) 2023 Sprinix Technolabs pvt Ltd.. (https://www.sprinix.com)
 */
namespace Sprinix\EstimateDate\Helper;
use Magento\Store\Model\ScopeInterface;
use Magento\Framework\App\Helper\AbstractHelper;

/**
 * Class Data
 * @package Sprinix\EstimateDate\Helper
 */
class Data extends AbstractHelper
{
    /**
     * extension enable or not
     */
    const IS_ENABLED            = 'estimatedate/general/enable';

    /**
     * holidays
     */
    const DISPLAY_DAYS         	= 'estimatedate/general/week_days';

    /**
     * from days
     */
    const DELIVERY_FROM         = 'estimatedate/general/start_from';

    /**
     * to days
     */
    const DELIVERY_TO           = 'estimatedate/general/end_to';
    /**
     * Display on page
     */
    const SELECT_PAGE           = 'estimatedate/general/page';

    /**
     * Selected DateFormat
     */
    const DATE_FORMAT           = 'estimatedate/general/date_format';
    /**
     * Delivery text
     */
    const DELIVERY_DATE_TEXT    = 'estimatedate/general/delivery_date_text';

    /**
     * delivery text constant
     */
    const SHOW_TEXT             = "Estimate Delivery Date";

    /**
     * product detail page
     */
    const  PRODUCT              = "Product";

    /**
     * cart page
     */
    const CART                  = "Cart";

    /**
     * checkout page
     */
    const CHECKOUT              = "Checkout";

    /**
     * success page
     */
    const SUCCESS               = "Success";

    /**
     * customer page
     */
    const CUSTOMER              = "Customer";

    /**
     * admin page
     */
    const ADMIN                 = "Admin";

    /**
     * simple type product
     */
    const  SIMPLE               = "simple";

    /**
     * product type configurable
     */
    const  CONFIGURABLE         = "configurable";

    /**
     * product type bundle
     */
    const   BUNDLE              =  "bundle";

    /**
     * product type grouped
     */
    const  GROUPED              =      "grouped";

    /**
     * Empty Day
     */
    const  EMPTYDAY            =      "7";

    /**
     * @return mixed
     */
    public function isEnabled()
    {
        $isEnabled = $this->scopeConfig->
        getValue(self::IS_ENABLED, ScopeInterface::SCOPE_STORE );
        return $isEnabled;
    }

    /**
     * @return mixed
     */
    public function  getDateFormat()
    {
        $dateFormat  = $this->scopeConfig->
        getValue(self::DATE_FORMAT, ScopeInterface::SCOPE_STORE);
        return $dateFormat;
    }

    /**
     * @return array
     */
    public function getPageSelect()
    {
        $selected_page = $this->scopeConfig->
        getValue(self::SELECT_PAGE, ScopeInterface::SCOPE_STORE);
         if ($selected_page) {
             return @explode(',', $selected_page);
         } else {
             return array();
         }
    }

    /**
     * @return mixed|null
     */
    public function getDays()
    {
        $holiday = $this->scopeConfig->
        getValue(self::DISPLAY_DAYS, ScopeInterface::SCOPE_STORE);
         if (!empty($holiday) || $holiday == '0') {
             return $holiday;
         }
         return self::EMPTYDAY;
    }

    /**
     * @return bool
     */
    public function checkDeliveryAvailable(){
        $length = count(explode(',',$this->getDays()));
        if($length == 7){
            return false;
        }
        return true;
    }

    /**
     * @return mixed|string
     */
    public function showDeliveryText()
    {
      $delivery_text =   $this->scopeConfig->
      getValue(self::DELIVERY_DATE_TEXT, ScopeInterface::SCOPE_STORE);
      if ($delivery_text) {
          return $delivery_text;
      }
      else {
          return (self::SHOW_TEXT);
      }
    }

    /**
     * @return mixed
     */
    public function defaultFrom()
    {
        $fromDays = $this->scopeConfig->
        getValue(self::DELIVERY_FROM, ScopeInterface::SCOPE_STORE);
       return $fromDays;
    }

    /**
     * @param $product
     * @return mixed|null
     */
    public function fromDays($product)
    {
        $from_days  = $product->getStartDate();
        $fromDays = $this->defaultFrom();
        if ($from_days) {
            return $from_days;
        } else {
            return $fromDays;
        }
    }

    /**
     * @return mixed
     */
    public function defaultTo(){
        $toDays = $this->scopeConfig->
        getValue(self::DELIVERY_TO, ScopeInterface::SCOPE_STORE);
        return $toDays;
    }

    /**
     * @param $product
     * @return mixed
     */
    public function toDays($product)
    {
        $to_days  = $product->getEndDate();
        $toDays = $this->defaultTo();
        if ($to_days) {
            return $to_days;
        }
        else  {
            return $toDays;
        }
    }

    /**
     * @param $product
     * @param $type
     * @return false|mixed|string
     */
    public function fromToDate($product, $type)
    {
            $days = null;
            if ($type == 'from') {
                $days = (int)$this->fromDays($product);
            } elseif ($type == 'to') {
                $days = (int)$this->toDays($product);
            }
            $dateFormat = $this->getDateFormat();
            $holiday = $this->getDays();
            $date = @date('Y-m-d');
            if ($days != "0") {
                while ($days > 0) {
                    $repeat = @strtotime("+1 day", @strtotime($date));
                    $date = @date('Y-m-d', $repeat);
                    $day = @date("w", @strtotime($date));
                    if (!@str_contains($holiday, $day)) {
                        $days--;
                    }
                }
            }
            if (@str_contains($dateFormat, 'YMD')) {
                $fromTo_date = @str_replace('-', '/', $date);
            } else {
                $fromTo_date = @date("d/m/Y", @strtotime($date));
            }
           return $fromTo_date;
    }

    /**
     * @param $product
     * @return string
     */
    public function deliveryDate($product)
    {
        $type = "from";
        $from = $this->fromToDate($product,$type);
        $type = "to";
        $to = $this->fromToDate($product,$type);
        if ($from && $to) {
            $deliveryDate = $from . " - " . $to;
            return $deliveryDate;
        }
    }

    /**
     * @param $product
     * @return array
     */
    public  function  estimateDeliveryDate($product)
    {
        $delivery_date_text = $this->showDeliveryText();
        $deliveryDate = $this->deliveryDate($product);
        if ($delivery_date_text && $deliveryDate) {
            $additionalOptions[] = [
                'label' => $delivery_date_text,
                'value' => $deliveryDate
            ];
            return $additionalOptions;
        }
    }

    /**
     * @param $product
     * @param $daysType
     * @return array
     */
    public function  configFromTo($product,$daysType)
    {
        $children = $product->getTypeInstance()->getUsedProducts($product);
        $deliveryDate = $childId = [];
        $fromTo ='';
        foreach ($children as $child) {
            $childId = $child->getId();
            $childDays = null;
            if ($daysType == "from_days") {
                $childDays = (int)$child->getStartDate();
                if (empty($childDays)){
                    $defaultFrom = (int)$this->defaultFrom();
                    $childDays =$defaultFrom;
                }
            }
            elseif ($daysType == "to_days") {
                $childDays = $child->getEndDate();
                if(empty($childDays)){
                    $defaultTo = $this->defaultTo();
                    $childDays = (int)$defaultTo;
                }
            }
            $holiday = $this->getDays();
            $date = @date('Y-m-d');
            if ($childDays != "0") {
                while ($childDays > 0) {
                    $repeat = @strtotime("+1 day", @strtotime($date));
                    $date = @date('Y-m-d', $repeat);
                    $day = @date("w", @strtotime($date));
                    $dateFormat = $this->getDateFormat();
                    if (!@str_contains($holiday, $day)) {
                        $childDays--;
                    }
                }
                if (@str_contains($dateFormat, 'YMD')) {
                    $fromTo = @str_replace('-', '/', $date);

                } else {
                    $fromTo = @date("d/m/Y", @strtotime($date));
                }
            }
            $deliveryDate[$childId] = $fromTo;
        }
        return $deliveryDate;
    }
}
