<?php

/**
 * @package     Sprinix_EstimateDate
 * @copyright   Copyright (c) 2023 Sprinix Technolabs pvt Ltd.. (https://www.sprinix.com)
 */
namespace Sprinix\EstimateDate\Observer;

use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Event\Observer;
use Sprinix\EstimateDate\Helper\Data;
use Magento\Framework\Serialize\SerializerInterface;
use Magento\Framework\App\RequestInterface;
use Magento\Checkout\Block\Cart\Item\Renderer;
use Magento\Sales\Block\Order\Item\Renderer\DefaultRenderer;
use Magento\Sales\Block\Adminhtml\Order\View\Items\Renderer\DefaultRenderer as AdminRenderer;


/**
 * Class HtmlBefore
 * @package Sprinix\EstimateDate\Observer
 */
class HtmlBefore implements ObserverInterface
{
    /**
     * @var SerializerInterface
     */
    private $serializer;

    /**
     * @var Data
     */
    protected $helper;

    /**
     * @var RequestInterface
     */
    protected $request;

    /**
     * HtmlBefore constructor.
     * @param Data $helper
     * @param RequestInterface $request
     * @param SerializerInterface $serializer
     */
    public function __construct(
        Data $helper,
        RequestInterface $request,
        SerializerInterface $serializer
    ) {
        $this->helper = $helper;
        $this->request = $request;
        $this->serializer = $serializer;
    }

    /**
     * @param Observer $observer
     */
    public function execute(Observer $observer)
    {
        $block = $observer->getBlock();
        $position = $this->helper->getPageSelect();
        $enable = $this->helper->isEnabled();
        $delivery_date_text = $this->helper->showDeliveryText();
        if (!$enable) {
            return;
        }
        switch (true) {
            case $block instanceof Renderer
                && $this->request->getModuleName() == 'checkout'
                && $this->request->getControllerName() == 'cart':
                if (@in_array(Data::CART, $position)) {
                    if ($item = $block->getItem()) {
                        $product = $block->getProduct()->load($item->getProductId());
                        $productType = $product->getTypeId();
                        $checkDelivery = $this->helper->checkDeliveryAvailable();
                        if($checkDelivery) {
                        if ($productType == Data::SIMPLE || $productType == Data::CONFIGURABLE
                            || $productType == Data::BUNDLE || $productType == Data::GROUPED) {
                            $deliveryDate = $this->helper->estimateDeliveryDate($product);
                                if (count($deliveryDate) > 0) {
                                    $item->addOption(array(
                                        'product_id' => $item->getProductId(),
                                        'code' => 'additional_options',
                                        'value' => $this->serializer->serialize($deliveryDate)
                                    ));
                                }
                            }
                        }
                    }
                } else {
                    if (@in_array(Data::CHECKOUT, $position)) {
                        if ($item = $block->getItem()) {
                            $additionalOptions = $item->getOptionByCode('additional_options');
                            if ($additionalOptions) {
                                $additional_option = $this->serializer->unserialize($additionalOptions->getValue());
                                foreach ($additional_option as $option => $value) {
                                    if ($value['label'] == $delivery_date_text) {
                                        unset($additional_option[$option]);
                                    }
                                }
                                $item->addOption(array(
                                    'product_id' => $item->getProductId(),
                                    'code' => 'additional_options',
                                    'value' => $this->serializer->serialize($additional_option)
                                ));
                            }
                        }
                    }
                }
                break;
            case @in_array(Data::CUSTOMER, $position)
                && $block instanceof DefaultRenderer
                && $this->request->getModuleName() == 'sales'
                && $this->request->getControllerName() == 'order':
            case @in_array(Data::ADMIN, $position)
                && $block instanceof AdminRenderer
                && $this->request->getModuleName() == 'sales'
                && $this->request->getControllerName() == 'order':
                if ($item = $block->getItem()) {
                    if ($deliveryDate = $item->getDeliveryDate()) {
                        $options = $item->getProductOptions();
                        $options['additional_options'] = $this->serializer->unserialize($deliveryDate);
                        $item->setProductOptions($options);
                    }
                }
                break;
        }
    }
}

