<?php

/**
 * @package     Sprinix_EstimateDate
 * @copyright   Copyright (c) 2023 Sprinix Technolabs pvt Ltd.. (https://www.sprinix.com)
 */
namespace Sprinix\EstimateDate\Observer;

use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Event\Observer;
use Magento\Catalog\Model\ProductRepository;
use Sprinix\EstimateDate\Helper\Data;
use Magento\Framework\Serialize\SerializerInterface;
use Psr\Log\LoggerInterface;

/**
 * Class OrderData
 * @package Sprinix\EstimateDate\Observer
 */
class OrderData implements ObserverInterface
{
    /**
     * @var ProductRepository
     */
    protected $productRepository;

    /**
     * @var Data
     */
    protected $helper;

    /**
     * @var SerializerInterface
     */
    private $serializer;

    /**
     * @var LoggerInterface
     */
    private  $logger;

    /**
     * OrderData constructor.
     * @param ProductRepository $productRepository
     * @param Data $helper
     * @param SerializerInterface $serializer
     * @param LoggerInterface $logger
     */
   public function __construct(
       ProductRepository $productRepository,
       Data $helper,
       SerializerInterface $serializer,
       LoggerInterface $logger
   ) {
        $this->productRepository = $productRepository;
        $this->helper = $helper;
        $this->serializer = $serializer;
        $this->logger = $logger;
   }

    /**
     * @param Observer $observer
     */
  public function execute(Observer $observer)
  {
    $order = $observer->getEvent()->getOrder();
    try {
        $delivery_date_text = $this->helper->showDeliveryText();
        $checkDelivery = $this->helper->checkDeliveryAvailable();
        if($checkDelivery) {
            foreach ($order->getAllVisibleItems() as $orderItem) {
              $additionalOptions = [];
              $productId = $orderItem->getProductId();
              $product = $this->productRepository->getById($productId);
              $productType = $product->getTypeId();
              $deliveryDate = $this->helper->deliveryDate($product);
              if ($productType == Data::SIMPLE || $productType == Data::CONFIGURABLE
                  || $productType == Data::BUNDLE || $productType == Data::GROUPED) {
                  if ($delivery_date_text && $deliveryDate) {
                      $additionalOptions[] = [
                          'label' => $delivery_date_text,
                          'value' => $deliveryDate
                      ];
                      $additionalOption = $this->serializer->serialize($additionalOptions);
                      $orderItem->setDeliveryDate($additionalOption);
                  }
              }
            }
        }
    } catch (\Exception $e) {
        $this->logger->info($e->getMessage());
    }
    return;
  }
}

