<?php

/**
 * @package     Sprinix_EstimateDate
 * @copyright   Copyright (c) 2023 Sprinix Technolabs pvt Ltd.. (https://www.sprinix.com)
 */
namespace Sprinix\EstimateDate\Plugin;

use Sprinix\EstimateDate\Helper\Data;
use Magento\Framework\Serialize\SerializerInterface;
use Magento\Framework\App\RequestInterface;
use Magento\Catalog\Model\ProductRepository;
use Psr\Log\LoggerInterface;

/**
 * Class QuoteItem
 * @package Sprinix\Estimatedate\Plugin
 */
class  QuoteItem
{
    /**
     * @var Data
     */
    protected $helper;

    /**
     * @var SerializerInterface
     */
    protected $serializer;

    /**
     * @var RequestInterface
     */
    protected $request;

    /**
     * @var ProductRepository
     */
    protected $productRepository;

    /**
     * @var LoggerInterface
     */
    private  $logger;

    /**
     * QuoteItem constructor.
     * @param Data $helper
     * @param SerializerInterface $serializer
     * @param RequestInterface $request
     * @param ProductRepository $productRepository
     * @param LoggerInterface $logger
     */
    public function __construct(
        Data $helper,
        SerializerInterface $serializer,
        RequestInterface $request,
        ProductRepository $productRepository,
        LoggerInterface $logger
    ) {
        $this->helper = $helper;
        $this->serializer = $serializer;
        $this->request = $request;
        $this->productRepository = $productRepository;
        $this->logger = $logger;
    }

    /**
     * @param $subject
     * @param $items
     * @return mixed
     */
    public function afterGetAllItems(\Magento\Quote\Model\Quote $subject, $items)
    {
        $position = $this->helper->getPageSelect();
        if ($this->helper->isEnabled()) {
            switch (true) {
                case @in_array(Data::CHECKOUT, $position)
                    && false !== @strpos($this->request->getModuleName(), 'checkout')
                    && $this->request->getControllerName() == 'index'
                    && $this->request->getActionName() != 'success':
                    foreach ($items as $item) {
                        if ($option = $this->getDeliveryDate($item)) {
                            if(count($option) > 0){
                                $item->addOption(array(
                                    'product_id' => $item->getProductId(),
                                    'code' => 'additional_options',
                                    'value' => $this->serializer->serialize($option)
                                ));
                                $item->saveItemOptions();
                            }
                        }
                    }
                    break;
            }
        }
        return $items;
    }

    /**
     * @param $item
     * @return array
     */
    protected function getDeliveryDate($item)
    {
        $deliveryDate = [];
        try {
           $product = $this->productRepository->getById($item->getProductId());
           $productType = $product->getTypeId();
            $checkDelivery = $this->helper->checkDeliveryAvailable();
           if ($checkDelivery) {
           $deliveryDate = $this->helper->estimateDeliveryDate($product);
           if ($productType == Data::SIMPLE || $productType == Data::CONFIGURABLE
               || $productType == Data::BUNDLE || $productType == Data::GROUPED) {

                       return $deliveryDate;
                   }
               }
        } catch (\Exception $e) {
            $this->logger->info($e->getMessage());
        }
        return $deliveryDate;
    }
}
