<?php

/**
 * @package     Sprinix_EstimateDate
 * @copyright   Copyright (c) 2023 Sprinix Technolabs pvt Ltd.. (https://www.sprinix.com)
 */
namespace Sprinix\EstimateDate\Setup\Patch\Data;
use Magento\Framework\Setup\ModuleDataSetupInterface;
use Magento\Eav\Setup\EavSetupFactory;
use Magento\Framework\Setup\Patch\DataPatchInterface;
use Magento\Eav\Model\Entity\Attribute\ScopedAttributeInterface;

/**
 * Class DeliveryDate
 * @package Sprinix\EstimateDate\Setup\Patch\Data
 */
class DeliveryDate implements DataPatchInterface
{
    /**
     * @var ModuleDataSetupInterface
     */
    protected $_moduleDataSetup;

    /**
     * @var EavSetupFactory
     */
    protected $_eavSetupFactory;

    /**
     * DeliveryDate constructor.
     * @param ModuleDataSetupInterface $moduleDataSetup
     * @param EavSetupFactory $eavSetupFactory
     */
    public function __construct(
        ModuleDataSetupInterface $moduleDataSetup,
        EavSetupFactory $eavSetupFactory
    )
    {
        $this->_moduleDataSetup = $moduleDataSetup;
        $this->_eavSetupFactory= $eavSetupFactory;
    }

    /**
     * @return DataPatchInterface|void
     */
    public function apply()
    {
        /** @var EavSetup $eavSetup */
        $eavSetup = $this->_eavSetupFactory->create(['setup' => $this->_moduleDataSetup]);
        $eavSetup->addAttribute('catalog_product', 'start_date', [
            'type' => 'text',
            'backend' => '',
            'frontend' => '',
            'label' => 'From Days',
            'input' => 'text',
            'class' => '',
            'source' => '',
            'global' => ScopedAttributeInterface::SCOPE_GLOBAL,
            'visible' => true,
            'required' => false,
            'user_defined' => false,
            'default' => '',
            'searchable' => false,
            'filterable' => false,
            'comparable' => false,
            'visible_on_front' => false,
            'used_in_product_listing' => true,
            'unique' => false,
            'note'=> 'Please enter a number in this field.',
            'apply_to' => 'simple,grouped,configurable,bundle',
        ]);
        $eavSetup->addAttribute('catalog_product', 'end_date', [
            'type' => 'text',
            'backend' => '',
            'frontend' => '',
            'label' => 'To Days',
            'input' => 'text',
            'class' => '',
            'source' => '',
            'global' => ScopedAttributeInterface::SCOPE_GLOBAL,
            'visible' => true,
            'required' => false,
            'user_defined' => false,
            'default' => '',
            'searchable' => false,
            'filterable' => false,
            'comparable' => false,
            'visible_on_front' => false,
            'used_in_product_listing' => true,
            'unique' => false,
            'note'=> 'Please enter a  number in this field.',
            'apply_to' => 'simple,grouped,configurable,bundle',
        ]);
    }

    /**
     * @return array|string[]
     */
    public static function getDependencies()
    {
        return [];
    }

    /**
     * @return array|string[]
     */
    public function getAliases()
    {
        return [];
    }

    /**
     * @return string
     */
    public static function getVersion()
    {
        return '1.0.3';
    }
}
